@@ -1,10 +1,6 @@
-import typing
 from abc import ABC
-
-try:
-    from contextlib import asynccontextmanager
-except ImportError:
-    from asyncio_extras import async_contextmanager as asynccontextmanager
+from contextlib import asynccontextmanager
+import typing
 
 
 class StateABC(ABC):
